parse_with_registry

Function parse_with_registry 

pub fn parse_with_registry(
    input: &str,
    registry: &ExtensionRegistry,
) -> Result<Plan, ParseError>
Parse a Substrait plan from text format with a custom extension registry.

Use this when the plan contains custom extensions registered via extensions::ExtensionRegistry. This is the parsing counterpart to format_with_registry.