format_with_registry

Function format_with_registry 

pub fn format_with_registry(
    plan: &Plan,
    options: &OutputOptions,
    registry: &ExtensionRegistry,
) -> (String, Vec<FormatError>)
Format a Substrait plan with custom options and an extension registry.

This function allows you to provide a custom extension registry for handling ExtensionLeaf, ExtensionSingle, and ExtensionMulti relations.

Example

use substrait_explain::{parse, format_with_registry, OutputOptions, ExtensionRegistry};

let mut registry = ExtensionRegistry::new();
// Register custom extensions...

let plan = parse("...").unwrap();
let (text, errors) = format_with_registry(&plan, &OutputOptions::default(), &registry);